@@ -17,7 +17,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#if !defined(__JSC_H_INSIDE__) && !defined(JSC_COMPILATION) && !defined(WEBKIT2_COMPILATION)
+#if !defined(__JSC_H_INSIDE__) && !defined(BUILDING_WEBKIT)
 #error "Only <jsc/jsc.h> can be included directly."
 #endif
 
@@ -44,7 +44,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define JSC_MINOR_VERSION (34)
+#define JSC_MINOR_VERSION (44)
 
 /**
  * JSC_MICRO_VERSION:
@@ -61,6 +61,8 @@ G_BEGIN_DECLS
  * @minor: minor version (e.g. 2 for version 1.2.5)
  * @micro: micro version (e.g. 5 for version 1.2.5)
  *
+ * Check the version of JSC header files at compile time.
+ *
  * Returns: %TRUE if the version of the JavaScriptCore header files
  * is the same as or newer than the passed-in version.
  */
